@@ -114,6 +114,8 @@ class MemoryCache(Cache):
     >>> data = {'key1':{'text':'text1', 'title':'title1'}}
     >>> mem = MemoryCache(SimpleNamespace(in_fields='title', out_fields='text,title', mem=data))
     >>> mem.write('key3', {'text': 'text3', 'title': 'title3'})
+    >>> data
+    {'key1': {'text': 'text1', 'title': 'title1'}, 'key3': {'text': 'text3', 'title': 'title3'}}
     >>> mem.read('key3')
     {'title': 'title3'}
     """
@@ -129,7 +131,9 @@ class MemoryCache(Cache):
         return dct
 
     def write(self, key, kvs):
-        self.config.mem[key] = kvs
+        if key not in self.config.mem:
+            self.config.mem[key] = {}
+        self.config.mem[key].update(kvs)
 
 
 class MySqlCache(Cache):
@@ -349,7 +353,7 @@ class AzureTableCache(Cache):
         if self.in_fields:
             fields = self.in_fields
         else:
-            fields = (k for k in entity.keys() if k not in ('PartitionKey', 'RowKey'))
+            fields = [k for k in entity.keys() if k not in ('PartitionKey', 'RowKey', 'Timestamp', 'etag')]
         return {k: v for k, v in entity.items() if k in fields}
 
     def write(self, key, kvs):
@@ -357,12 +361,36 @@ class AzureTableCache(Cache):
             a set is managed for each key to contain fields available
             a key:field -> value for accessing field for each key
         """
-        kvs.update({
+        dct = {
             'PartitionKey': 'key',
             'RowKey': key,
-        })
+        }
+        dct.update(kvs)
         self.service.insert_or_merge_entity(
             self.config.table,
-            kvs,
+            dct,
             timeout=5.0,
         )
+
+
+class CachedMessageMixin(object):
+    """
+    """
+    def get(self, key, default=None):
+        value = self.dct.get(key)
+        if value is None:
+            if not hasattr(self, 'fetched'):
+                self.fetched = self.cache.read(self.dct[self.keyname])
+            value = self.fetched.get(key, default)
+        return value
+
+    def update(self, other):
+        self.cache.write(self.dct[self.keyname], other)
+
+    def replace(self, other):
+        """ Not supported in cache mode """
+        raise NotImplementedError(".replace() is not supported in cache mode")
+
+
+def CachedMessageClass(messageClass, cache):
+    return type('CachedMessage', (CachedMessageMixin, messageClass), dict(cache=cache))
