@@ -6,7 +6,7 @@ import traceback
 from abc import ABC
 from copy import copy
 
-from .cache import CacheOf
+from .cache import CacheOf, CachedMessageClass
 from .exception import PipelineError
 from .message import Message
 from .monitor import Monitor
@@ -89,16 +89,20 @@ class WorkerCore(ABC):
         if self.cacheKind:
             self.cacheClass = CacheOf(self.cacheKind)
         self._add_arguments(self.parser)
+
         if config:
             self.parser.set_defaults(**config)
-        self.parser.set_defaults(message=self.messageClass)
         self.options = self.parser.parse_args(extras)
+
+        if self.cacheKind:
+            self.cache = self.cacheClass(self.options, logger=self.logger)
+            self.options.message = CachedMessageClass(self.messageClass, self.cache)
+        else:
+            self.options.message = self.messageClass
         if self.flag != WorkerConfig.NO_INPUT:
             self.source = self.sourceClass(self.options, logger=self.logger)
         if self.flag != WorkerConfig.NO_OUTPUT:
             self.destination = self.destinationClass(self.options, logger=self.logger)
-        if self.cacheKind:
-            self.cache = self.cacheClass(self.options, logger=self.logger)
         # report worker info to monitor
         self.monitor.record_worker_info()
 
@@ -136,13 +140,16 @@ class Generator(WorkerCore):
         if not self.generator:
             self.generator = self.generate()
         dct = next(self.generator)
-        msg = self.messageClass(dct)
+        msg = self.messageClass({})
+        msg.update(dct)
         msg.update_version(self.name, self.version)
         self.logger.info('Generated %s', msg)
         if msg.is_valid():
             self.logger.info('Writing %s', msg)
             self.destination.write(msg)
             self.monitor.record_write(self.destination.topic)
+        elif msg.terminated:
+            self.logger.info('Message terminates here')
         else:
             self.logger.error('Generated message is invalid, skipping')
             self.logger.error(msg.log_info())
@@ -359,7 +366,8 @@ class Processor(WorkerCore):
             self.monitor.record_read(self.source.topic)
             self.logger.info("Received %d-th message '%s'", i, str(msg))
 
-            self._step(msg)
+            with self.monitor.process_timer.time():
+                self._step(msg)
 
             self.source.acknowledge()
 
@@ -401,6 +409,7 @@ class Processor(WorkerCore):
                 self.destination.close()
         except PipelineError as e:
             e.log(self.logger)
+            self.logger.error(traceback.format_exc())
         except Exception as e:
             self.logger.error(traceback.format_exc())
             self.monitor.record_error(str(e))
